@@ -11,10 +11,10 @@ class Main(ExamplePage):
 </ul>
 <p>With the default settings,</p>
 <ul>
-<li>you must have the PostgreSQL database installed</li>
-<li>you must have created a database with the name "demo"</li>
-<li>the Application server user must have access to "demo"</li>
-<li>the PyGreSQL adapter must be installed</li>
+<li>you must have the PostgreSQL database</li>
+<li>and the PyGreSQL adapter installed, and</li>
+<li>you must have created a database with the name "demo" and</li>
+<li>a database user with the name "demo" and password "demo".</li>
 </ul>
 <p><a href="DBUtilsExample">Start the demo!</a></p>
 ''')
