@@ -51,7 +51,7 @@ an instance of PooledPg, passing the following parameters:
 For instance, if you want a pool of at least five connections
 to your local database 'mydb':
 
-	from PooledPg import PooledPg
+	from DBUtils.PooledPg import PooledPg
 	pool = PooledPg(5, dbname='mydb')
 
 Once you have set up the connection pool you can request
@@ -98,17 +98,23 @@ Licensed under the Open Software License version 2.1.
 
 """
 
-__version__ = '0.9.2'
-__revision__ = "$Rev: 5514 $"
-__date__ = "$Date: 2006-07-29 00:50:59 -0600 (Sat, 29 Jul 2006) $"
+__version__ = '0.9.3'
+__revision__ = "$Rev: 6563 $"
+__date__ = "$Date: 2007-05-18 13:20:02 -0600 (Fri, 18 May 2007) $"
 
 
-from SteadyPg import SteadyPgConnection
 from Queue import Queue, Empty, Full
 
-class PooledPgError(Exception): pass
-class InvalidConnection(PooledPgError): pass
-class TooManyConnections(PooledPgError): pass
+from DBUtils.SteadyPg import SteadyPgConnection
+
+class PooledPgError(Exception):
+	"""General PooledPg error."""
+
+class InvalidConnection(PooledPgError):
+	"""Database connection is invalid."""
+
+class TooManyConnections(PooledPgError):
+	"""Too many database connections were opened."""
 
 
 class PooledPg:
