@@ -26,7 +26,7 @@ After you have established your connection pool, stating the
 number of connections to be cached in the pool and the
 connection parameters, e.g.
 
-	from SimplePooledPg import PooledPg
+	from DBUtils.SimplePooledPg import PooledPg
 	dbpool = PooledPg(5, host=..., database=..., user=..., ...)
 
 you can demand database connections from that pool,
@@ -68,9 +68,9 @@ Licensed under the Open Software License version 2.1.
 
 """
 
-__version__ = '0.9.2'
-__revision__ = "$Rev: 5514 $"
-__date__ = "$Date: 2006-07-29 00:50:59 -0600 (Sat, 29 Jul 2006) $"
+__version__ = '0.9.3'
+__revision__ = "$Rev: 6563 $"
+__date__ = "$Date: 2007-05-18 13:20:02 -0600 (Fri, 18 May 2007) $"
 
 
 from pg import DB as PgConnection
@@ -81,6 +81,7 @@ class PooledPgConnection:
 
 	You don't normally deal with this class directly,
 	but use PooledPg to get new connections.
+
 	"""
 
 	def __init__(self, pool, con):
@@ -108,6 +109,7 @@ class PooledPg:
 
 	After you have created the connection pool,
 	you can get connections using getConnection().
+
 	"""
 
 	def __init__(self, maxconnections, *args, **kwargs):
@@ -116,6 +118,7 @@ class PooledPg:
 		maxconnections: the number of connections cached in the pool
 		args, kwargs: the parameters that shall be used to establish
 			the PostgreSQL connections using pg.connect()
+
 		"""
 		# Since there is no connection level safety, we
 		# build the pool using the synchronized queue class
