@@ -11,21 +11,18 @@ Copyright and credit info:
 
 """
 
-__version__ = '0.9.2'
-__revision__ = "$Rev: 5514 $"
-__date__ = "$Date: 2006-07-29 00:50:59 -0600 (Sat, 29 Jul 2006) $"
+__version__ = '0.9.3'
+__revision__ = "$Rev: 6571 $"
+__date__ = "$Date: 2007-05-21 16:52:12 -0600 (Mon, 21 May 2007) $"
 
 
 import sys
-
-# The TestSteadyDB module serves as a mock object for the DB-API 2 module:
-
-import TestSteadyDB
-dbapi = TestSteadyDB
-
 import unittest
-sys.path.insert(1, '..')
-from PersistentDB import PersistentDB
+
+sys.path.insert(1, '../..')
+# The TestSteadyDB module serves as a mock object for the DB-API 2 module:
+from DBUtils.Testing import TestSteadyDB as dbapi
+from DBUtils.PersistentDB import PersistentDB
 
 
 class TestPersistentDB(unittest.TestCase):
@@ -35,11 +32,11 @@ class TestPersistentDB(unittest.TestCase):
 
 	def test0_CheckVersion(self):
 		TestPersistentDBVersion = __version__
-		from PersistentDB import __version__ as PersistentDBVersion
+		from DBUtils.PersistentDB import __version__ as PersistentDBVersion
 		self.assertEqual(PersistentDBVersion, TestPersistentDBVersion)
 
 	def test1_NoThreadsafety(self):
-		from PersistentDB import NotSupportedError
+		from DBUtils.PersistentDB import NotSupportedError
 		for dbapi.threadsafety in (None, 0):
 			self.assertRaises(NotSupportedError, PersistentDB, dbapi)
 
@@ -71,10 +68,14 @@ class TestPersistentDB(unittest.TestCase):
 			this_db = persist.connection()
 			while 1:
 				try:
-					q = queryQueue[i].get(1, 1)
+					try:
+						q = queryQueue[i].get(1, 1)
+					except TypeError:
+						q = queryQueue[i].get(1)
 				except Empty:
 					q = None
-				if not q: break
+				if not q:
+					break
 				db = persist.connection()
 				if db != this_db:
 					r = 'error - not persistent'
@@ -90,7 +91,10 @@ class TestPersistentDB(unittest.TestCase):
 						r = cursor.fetchone()
 						cursor.close()
 				r = '%d(%d): %s' % (i, db._usage, r)
-				resultQueue[i].put(r, 1, 0.1)
+				try:
+					resultQueue[i].put(r, 1, 0.1)
+				except TypeError:
+					resultQueue[i].put(r, 1)
 			db.close()
 		from threading import Thread
 		threads = []
@@ -99,35 +103,68 @@ class TestPersistentDB(unittest.TestCase):
 			threads.append(thread)
 			thread.start()
 		for i in range(numThreads):
-			queryQueue[i].put('ping', 1, 0.1)
+			try:
+				queryQueue[i].put('ping', 1, 0.1)
+			except TypeError:
+				queryQueue[i].put('ping', 1)
 		for i in range(numThreads):
-			r = resultQueue[i].get(1, 0.1)
+			try:
+				r = resultQueue[i].get(1, 0.1)
+			except TypeError:
+				r = resultQueue[i].get(1)
 			self.assertEqual(r, '%d(0): ok - thread alive' % i)
 			self.assert_(threads[i].isAlive())
 		for i in range(numThreads):
 			for j in range(i + 1):
-				queryQueue[i].put('select test%d' % j, 1, 0.1)
-				r = resultQueue[i].get(1, 0.1)
+				try:
+					queryQueue[i].put('select test%d' % j, 1, 0.1)
+					r = resultQueue[i].get(1, 0.1)
+				except TypeError:
+					queryQueue[i].put('select test%d' % j, 1)
+					r = resultQueue[i].get(1)
 				self.assertEqual(r, '%d(%d): test%d' % (i, j + 1, j))
-		queryQueue[1].put('select test4', 1, 0.1)
-		r = resultQueue[1].get(1, 0.1)
-		self.assertEqual(r, '1(3): test4')
-		queryQueue[1].put('close', 1, 0.1)
-		r = resultQueue[1].get(1, 0.1)
-		self.assertEqual(r, '1(0): ok - connection closed')
-		for j in range(2):
-			queryQueue[1].put('select test%d' % j, 1, 0.1)
+		try:
+			queryQueue[1].put('select test4', 1, 0.1)
+		except TypeError:
+			queryQueue[1].put('select test4', 1)
+		try:
 			r = resultQueue[1].get(1, 0.1)
+		except TypeError:
+			r = resultQueue[1].get(1)
+		self.assertEqual(r, '1(3): test4')
+		try:
+			queryQueue[1].put('close', 1, 0.1)
+			r = resultQueue[1].get(1, 0.1)
+		except TypeError:
+			queryQueue[1].put('close', 1)
+			r = resultQueue[1].get(1)
+		self.assertEqual(r, '1(3): ok - connection closed')
+		for j in range(2):
+			try:
+				queryQueue[1].put('select test%d' % j, 1, 0.1)
+				r = resultQueue[1].get(1, 0.1)
+			except TypeError:
+				queryQueue[1].put('select test%d' % j, 1)
+				r = resultQueue[1].get(1)
 			self.assertEqual(r, '1(%d): test%d' % (j + 1, j))
 		for i in range(numThreads):
 			self.assert_(threads[i].isAlive())
-			queryQueue[i].put('ping', 1, 0.1)
+			try:
+				queryQueue[i].put('ping', 1, 0.1)
+			except TypeError:
+				queryQueue[i].put('ping', 1)
 		for i in range(numThreads):
-			r = resultQueue[i].get(1, 0.1)
+			try:
+				r = resultQueue[i].get(1, 0.1)
+			except TypeError:
+				r = resultQueue[i].get(1)
 			self.assertEqual(r, '%d(%d): ok - thread alive' % (i, i + 1))
 			self.assert_(threads[i].isAlive())
 		for i in range(numThreads):
-			queryQueue[i].put(None, 1, 1)
+			try:
+				queryQueue[i].put(None, 1, 1)
+			except TypeError:
+				queryQueue[i].put(None, 1)
 
 	def test4_PersistentDBMaxUsage(self):
 		persist = PersistentDB(dbapi, 20)
