@@ -11,27 +11,25 @@ Copyright and credit info:
 
 """
 
-__version__ = '0.9.2'
-__revision__ = "$Rev: 5514 $"
-__date__ = "$Date: 2006-07-29 00:50:59 -0600 (Sat, 29 Jul 2006) $"
+__version__ = '0.9.3'
+__revision__ = "$Rev: 6563 $"
+__date__ = "$Date: 2007-05-18 13:20:02 -0600 (Fri, 18 May 2007) $"
 
 
 import sys
-
-# This module also serves as a mock object for the pg API module:
-
-import TestSteadyPg
-
 import unittest
-sys.path.insert(1, '..')
-from PersistentPg import PersistentPg
+
+sys.path.insert(1, '../..')
+# The TestSteadyPg module serves as a mock object for the pg API module:
+from DBUtils.Testing import TestSteadyPg
+from DBUtils.PersistentPg import PersistentPg
 
 
 class TestPersistentPg(unittest.TestCase):
 
 	def test0_CheckVersion(self):
 		TestPersistentPgVersion = __version__
-		from PersistentPg import __version__ as PersistentPgVersion
+		from DBUtils.PersistentPg import __version__ as PersistentPgVersion
 		self.assertEqual(PersistentPgVersion, TestPersistentPgVersion)
 
 	def test1_PersistentPgClose(self):
@@ -63,10 +61,14 @@ class TestPersistentPg(unittest.TestCase):
 			this_db = persist.connection().db
 			while 1:
 				try:
-					q = queryQueue[i].get(1, 1)
+					try:
+						q = queryQueue[i].get(1, 1)
+					except TypeError:
+						q = queryQueue[i].get(1)
 				except Empty:
 					q = None
-				if not q: break
+				if not q:
+					break
 				db = persist.connection()
 				if db.db != this_db:
 					r = 'error - not persistent'
@@ -79,7 +81,10 @@ class TestPersistentPg(unittest.TestCase):
 					else:
 						r = db.query(q)
 				r = '%d(%d): %s' % (i, db._usage, r)
-				resultQueue[i].put(r, 1, 0.1)
+				try:
+					resultQueue[i].put(r, 1, 0.1)
+				except TypeError:
+					resultQueue[i].put(r, 1)
 			db.close()
 		from threading import Thread
 		threads = []
@@ -88,35 +93,66 @@ class TestPersistentPg(unittest.TestCase):
 			threads.append(thread)
 			thread.start()
 		for i in range(numThreads):
-			queryQueue[i].put('ping', 1, 0.1)
+			try:
+				queryQueue[i].put('ping', 1, 0.1)
+			except TypeError:
+				queryQueue[i].put('ping', 1)
 		for i in range(numThreads):
-			r = resultQueue[i].get(1, 0.1)
+			try:
+				r = resultQueue[i].get(1, 0.1)
+			except TypeError:
+				r = resultQueue[i].get(1)
 			self.assertEqual(r, '%d(0): ok - thread alive' % i)
 			self.assert_(threads[i].isAlive())
 		for i in range(numThreads):
 			for j in range(i + 1):
-				queryQueue[i].put('select test%d' % j, 1, 0.1)
-				r = resultQueue[i].get(1, 0.1)
+				try:
+					queryQueue[i].put('select test%d' % j, 1, 0.1)
+					r = resultQueue[i].get(1, 0.1)
+				except TypeError:
+					queryQueue[i].put('select test%d' % j, 1)
+					r = resultQueue[i].get(1)
 				self.assertEqual(r, '%d(%d): test%d' % (i, j + 1, j))
-		queryQueue[1].put('select test4', 1, 0.1)
-		r = resultQueue[1].get(1, 0.1)
+		try:
+			queryQueue[1].put('select test4', 1, 0.1)
+			r = resultQueue[1].get(1, 0.1)
+		except TypeError:
+			queryQueue[1].put('select test4', 1)
+			r = resultQueue[1].get(1)
 		self.assertEqual(r, '1(3): test4')
-		queryQueue[1].put('close', 1, 0.1)
-		r = resultQueue[1].get(1, 0.1)
+		try:
+			queryQueue[1].put('close', 1, 0.1)
+			r = resultQueue[1].get(1, 0.1)
+		except TypeError:
+			queryQueue[1].put('close', 1)
+			r = resultQueue[1].get(1)
 		self.assertEqual(r, '1(3): ok - connection closed')
 		for j in range(2):
-			queryQueue[1].put('select test%d' % j, 1, 0.1)
-			r = resultQueue[1].get(1, 0.1)
+			try:
+				queryQueue[1].put('select test%d' % j, 1, 0.1)
+				r = resultQueue[1].get(1, 0.1)
+			except TypeError:
+				queryQueue[1].put('select test%d' % j, 1)
+				r = resultQueue[1].get(1)
 			self.assertEqual(r, '1(%d): test%d' % (j + 1, j))
 		for i in range(numThreads):
 			self.assert_(threads[i].isAlive())
-			queryQueue[i].put('ping', 1, 0.1)
+			try:
+				queryQueue[i].put('ping', 1, 0.1)
+			except TypeError:
+				queryQueue[i].put('ping', 1)
 		for i in range(numThreads):
-			r = resultQueue[i].get(1, 0.1)
+			try:
+				r = resultQueue[i].get(1, 0.1)
+			except TypeError:
+				r = resultQueue[i].get(1)
 			self.assertEqual(r, '%d(%d): ok - thread alive' % (i, i + 1))
 			self.assert_(threads[i].isAlive())
 		for i in range(numThreads):
-			queryQueue[i].put(None, 1, 1)
+			try:
+				queryQueue[i].put(None, 1, 1)
+			except TypeError:
+				queryQueue[i].put(None, 1)
 
 	def test3_PersistentPgMaxUsage(self):
 		persist = PersistentPg(20)
