@@ -11,32 +11,29 @@ Copyright and credit info:
 
 """
 
-__version__ = '0.9.2'
-__revision__ = "$Rev: 5514 $"
-__date__ = "$Date: 2006-07-29 00:50:59 -0600 (Sat, 29 Jul 2006) $"
+__version__ = '0.9.3'
+__revision__ = "$Rev: 6563 $"
+__date__ = "$Date: 2007-05-18 13:20:02 -0600 (Fri, 18 May 2007) $"
 
 
 import sys
-
-# The TestSteadyDB module serves as a mock object for the DB-API 2 module:
-
-import TestSteadyDB
-dbapi = TestSteadyDB
-
 import unittest
-sys.path.insert(1, '..')
-from PooledDB import PooledDB
+
+sys.path.insert(1, '../..')
+# The TestSteadyDB module serves as a mock object for the DB-API 2 module:
+from DBUtils.Testing import TestSteadyDB as dbapi
+from DBUtils.PooledDB import PooledDB
 
 
 class TestPooledDB(unittest.TestCase):
 
 	def test00_CheckVersion(self):
 		TestPooledDBVersion = __version__
-		from PooledDB import __version__ as PooledDBVersion
+		from DBUtils.PooledDB import __version__ as PooledDBVersion
 		self.assertEqual(PooledDBVersion, TestPooledDBVersion)
 
 	def test01_NoThreadsafety(self):
-		from PooledDB import NotSupportedError
+		from DBUtils.PooledDB import NotSupportedError
 		for threadsafety in (None, 0):
 			dbapi.threadsafety = threadsafety
 			self.assertRaises(NotSupportedError, PooledDB, dbapi)
@@ -71,7 +68,7 @@ class TestPooledDB(unittest.TestCase):
 			self.assert_(hasattr(pool, '_setsession'))
 			self.assert_(pool._setsession is None)
 			con = pool._idle_cache[0]
-			from SteadyDB import SteadyDBConnection
+			from DBUtils.SteadyDB import SteadyDBConnection
 			self.assert_(isinstance(con, SteadyDBConnection))
 			self.assert_(hasattr(con, '_maxusage'))
 			self.assertEqual(con._maxusage, 0)
@@ -157,7 +154,7 @@ class TestPooledDB(unittest.TestCase):
 				self.assertEqual(shared_con.shared, 1)
 				self.assert_(hasattr(shared_con, 'con'))
 				self.assertEqual(shared_con.con, con)
-			from SteadyDB import SteadyDBConnection
+			from DBUtils.SteadyDB import SteadyDBConnection
 			self.assert_(isinstance(con, SteadyDBConnection))
 			self.assert_(hasattr(con, '_con'))
 			db_con = con._con
@@ -590,7 +587,7 @@ class TestPooledDB(unittest.TestCase):
 				'doit2', 'commit', 'rollback'])
 
 	def test12_MaxConnections(self):
-		from PooledDB import TooManyConnections
+		from DBUtils.PooledDB import TooManyConnections
 		for threadsafety in (1, 2):
 			dbapi.threadsafety = threadsafety
 			shareable = threadsafety > 1
@@ -917,19 +914,32 @@ class TestPooledDB(unittest.TestCase):
 			from Queue import Queue, Empty
 			queue = Queue(3)
 			def connection():
-				queue.put(pool.connection(), 1, 0.1)
+				try:
+					queue.put(pool.connection(), 1, 0.1)
+				except Exception:
+					queue.put(pool.connection(), 1)
 			from threading import Thread
 			for i in range(3):
 				Thread(target=connection).start()
-			db1 = queue.get(1, 0.1)
-			db2 = queue.get(1, 0.1)
+			try:
+				db1 = queue.get(1, 0.1)
+				db2 = queue.get(1, 0.1)
+			except TypeError:
+				db1 = queue.get(1)
+				db2 = queue.get(1)
 			self.assertNotEqual(db1, db2)
 			db1_con = db1._con
 			db2_con = db2._con
 			self.assertNotEqual(db1_con, db2_con)
-			self.assertRaises(Empty, queue.get, 1, 0.1)
+			try:
+				self.assertRaises(Empty, queue.get, 1, 0.1)
+			except TypeError:
+				self.assertRaises(Empty, queue.get, 0)
 			del db1
-			db1 = queue.get(1, 0.1)
+			try:
+				db1 = queue.get(1, 0.1)
+			except TypeError:
+				db1 = queue.get(1)
 			self.assertNotEqual(db1, db2)
 			self.assertNotEqual(db1._con, db2._con)
 			self.assertEqual(db1._con, db1_con)
@@ -941,9 +951,15 @@ class TestPooledDB(unittest.TestCase):
 			db2_con = db2._con
 			self.assertNotEqual(db1_con, db2_con)
 			Thread(target=connection).start()
-			self.assertRaises(Empty, queue.get, 1, 0.1)
+			try:
+				self.assertRaises(Empty, queue.get, 1, 0.1)
+			except TypeError:
+				self.assertRaises(Empty, queue.get, 0)
 			del db1
-			db1 = queue.get(1, 0.1)
+			try:
+				db1 = queue.get(1, 0.1)
+			except TypeError:
+				db1 = queue.get(1)
 			self.assertNotEqual(db1, db2)
 			self.assertNotEqual(db1._con, db2._con)
 			self.assertEqual(db1._con, db1_con)
