@@ -12,9 +12,9 @@ Copyright and credit info:
 
 """
 
-__version__ = '0.9.2'
-__revision__ = "$Rev: 5514 $"
-__date__ = "$Date: 2006-07-29 00:50:59 -0600 (Sat, 29 Jul 2006) $"
+__version__ = '0.9.3'
+__revision__ = "$Rev: 6563 $"
+__date__ = "$Date: 2007-05-18 13:20:02 -0600 (Fri, 18 May 2007) $"
 
 
 import sys
@@ -43,8 +43,8 @@ class Connection:
 
 
 import unittest
-sys.path.insert(1, '..')
-import SimplePooledDB
+sys.path.insert(1, '../..')
+from DBUtils import SimplePooledDB
 
 
 class TestSimplePooledDB(unittest.TestCase):
@@ -127,13 +127,23 @@ class TestSimplePooledDB(unittest.TestCase):
 		thread1 = Thread(target=connection).start()
 		thread2 = Thread(target=connection).start()
 		thread3 = Thread(target=connection).start()
-		db1 = queue.get(1, 1)
-		db2 = queue.get(1, 1)
+		try:
+			db1 = queue.get(1, 1)
+			db2 = queue.get(1, 1)
+		except TypeError:
+			db1 = queue.get(1)
+			db2 = queue.get(1)
 		self.assertNotEqual(db1, db2)
 		self.assertNotEqual(db1._con, db2._con)
-		self.assertRaises(Empty, queue.get, 1, 0.1)
+		try:
+			self.assertRaises(Empty, queue.get, 1, 0.1)
+		except TypeError:
+			self.assertRaises(Empty, queue.get, 0)
 		db2.close()
-		db3 = queue.get(1, 1)
+		try:
+			db3 = queue.get(1, 1)
+		except TypeError:
+			db3 = queue.get(1)
 		self.assertNotEqual(db1, db3)
 		self.assertNotEqual(db1._con, db3._con)
 
